@@ -6,9 +6,4 @@
 // TODO: only expose what is actually used
 #![allow(dead_code)]
 
-// include!("../../graphblas_implementation/bindings.rs");
-include!(concat!(
-    env!("OUT_DIR"),
-    "/",
-    "suitesparse_graphblas_bindings.rs"
-));
+include!("../../graphblas_implementation/suitesparse_graphblas_bindings.rs");
