@@ -6,12 +6,12 @@ use crate::error::SparseLinearAlgebraError;
 use crate::operators::{
     binary_operator::BinaryOperator, mask::VectorMask, options::OperatorOptions,
 };
-use crate::sparse_matrix::SparseMatrix;
-use crate::sparse_vector::SparseVector;
 use crate::util::{
     ElementIndex, ElementIndexSelector, ElementIndexSelectorGraphblasType, IndexConversion,
 };
-use crate::value_type::{AsBoolean, ValueType};
+use crate::value_types::sparse_matrix::SparseMatrix;
+use crate::value_types::sparse_vector::SparseVector;
+use crate::value_types::value_type::{AsBoolean, ValueType};
 
 use crate::bindings_to_graphblas_implementation::{
     GrB_BinaryOp, GrB_Descriptor, GxB_Col_subassign,
@@ -19,6 +19,33 @@ use crate::bindings_to_graphblas_implementation::{
 
 // TODO: explicitly define how dupicates are handled
 
+// Implemented methods do not provide mutable access to GraphBLAS operators or options.
+// Code review must consider that no mtable access is provided.
+// https://doc.rust-lang.org/nomicon/send-and-sync.html
+unsafe impl Send for InsertVectorIntoSubColumn<bool, bool> {}
+unsafe impl Send for InsertVectorIntoSubColumn<u8, u8> {}
+unsafe impl Send for InsertVectorIntoSubColumn<u16, u16> {}
+unsafe impl Send for InsertVectorIntoSubColumn<u32, u32> {}
+unsafe impl Send for InsertVectorIntoSubColumn<u64, u64> {}
+unsafe impl Send for InsertVectorIntoSubColumn<i8, i8> {}
+unsafe impl Send for InsertVectorIntoSubColumn<i16, i16> {}
+unsafe impl Send for InsertVectorIntoSubColumn<i32, i32> {}
+unsafe impl Send for InsertVectorIntoSubColumn<i64, i64> {}
+unsafe impl Send for InsertVectorIntoSubColumn<f32, f32> {}
+unsafe impl Send for InsertVectorIntoSubColumn<f64, f64> {}
+
+unsafe impl Sync for InsertVectorIntoSubColumn<bool, bool> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<u8, u8> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<u16, u16> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<u32, u32> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<u64, u64> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<i8, i8> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<i16, i16> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<i32, i32> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<i64, i64> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<f32, f32> {}
+unsafe impl Sync for InsertVectorIntoSubColumn<f64, f64> {}
+
 #[derive(Debug, Clone)]
 pub struct InsertVectorIntoSubColumn<MatrixToInsertInto: ValueType, VectorToInsert: ValueType> {
     _matrix_to_insert_into: PhantomData<MatrixToInsertInto>,
@@ -221,12 +248,12 @@ mod tests {
 
     use crate::context::{Context, Mode};
     use crate::operators::binary_operator::First;
-    use crate::sparse_matrix::{
+    use crate::util::ElementIndex;
+    use crate::value_types::sparse_matrix::{
         FromMatrixElementList, GetMatrixElementValue, MatrixElementList, Size,
     };
-    use crate::sparse_vector::FromVectorElementList;
-    use crate::sparse_vector::VectorElementList;
-    use crate::util::ElementIndex;
+    use crate::value_types::sparse_vector::FromVectorElementList;
+    use crate::value_types::sparse_vector::VectorElementList;
 
     #[test]
     fn test_insert_vector_into_column() {
